#!/usr/bin/env python

from omics_pipe.parameters.default_parameters import default_parameters
from omics_pipe.utils import *
p = Bunch(default_parameters)


def GATK_target_coverage(sample, GATK_target_coverage_flag):
    '''GATK preprocessing steps for whole exome sequencing.

    input:
        recal.FULL.bam
    output:
        stat/s_$2_recal_target.sample_statistics
    citation:
        McKenna A, Hanna M, Banks E, Sivachenko A, Cibulskis K, Kernytsky A, Garimella K, Altshuler D, Gabriel S, Daly M, DePristo MA (2010). The Genome Analysis Toolkit: a MapReduce framework for analyzing next-generation DNA sequencing data. Genome Res. 20:1297-303.
    link:
        http://www.broadinstitute.org/gatk/
    parameters from parameters file:
        BWA_RESULTS:

        sample:

        TEMP_DIR:

        GATK_VERSION:

        GENOME:

        DBSNP:

        TARGET_FLANKS_FILE:

        GATK_THREADS:  
      '''

    spawn_job(jobname = 'GATK_target_coverage', SAMPLE = sample, LOG_PATH = p.LOG_PATH, RESULTS_EMAIL = p.RESULTS_EMAIL, SCHEDULER = p.SCHEDULER, walltime = "240:00:00", queue = p.QUEUE, nodes = 1, ppn = 4, memory = "8gb", script = "/GATK_depthOfCoverage_DRAW.sh", args_list = [p.BWA_RESULTS, sample, p.TEMP_DIR, p.GATK_VERSION, p.GENOME, p.DBSNP, p.TARGET_FLANKS_FILE, p.GATK_THREADS])
    job_status(jobname = 'GATK_target_coverage', resultspath = p.BWA_RESULTS, SAMPLE = sample,  outputfilename = sample + "/" + "stat" + "/s_"+ sample +"_recal_target.coverage.sample_summary", FLAG_PATH = p.FLAG_PATH)
    return


def GATK_genome_coverage(sample, GATK_genome_coverage_flag):
    '''GATK preprocessing steps for whole exome sequencing.

    input:
        recal.FULL.bam
    output:
        stat/s_$2_recal_genome.sample_statistics
    citation:
        McKenna A, Hanna M, Banks E, Sivachenko A, Cibulskis K, Kernytsky A, Garimella K, Altshuler D, Gabriel S, Daly M, DePristo MA (2010). The Genome Analysis Toolkit: a MapReduce framework for analyzing next-generation DNA sequencing data. Genome Res. 20:1297-303.
    link:
        http://www.broadinstitute.org/gatk/
    parameters from parameters file:
        BWA_RESULTS:

        sample:

        TEMP_DIR:

        GATK_VERSION:

        GENOME:

        DBSNP:

        TARGET_FLANKS_FILE:

        GATK_THREADS:

        '''

    spawn_job(jobname = 'GATK_genome_coverage', SAMPLE = sample, LOG_PATH = p.LOG_PATH, RESULTS_EMAIL = p.RESULTS_EMAIL, SCHEDULER = p.SCHEDULER, walltime = "240:00:00", queue = p.QUEUE, nodes = 1, ppn = 4, memory = "10gb", script = "/GATK_depthOfCoverageGenome_DRAW.sh", args_list = [p.BWA_RESULTS, sample, p.TEMP_DIR, p.GATK_VERSION, p.GENOME, p.DBSNP, p.TARGET_FLANKS_FILE, p.GATK_THREADS])
    job_status(jobname = 'GATK_genome_coverage', resultspath = p.BWA_RESULTS, SAMPLE = sample,  outputfilename = sample + "/" + "stat" + "/s_"+ sample +"_recal_genome.coverage.sample_summary", FLAG_PATH = p.FLAG_PATH)
    return


if __name__ == '__main__':
    GATK_target_coverage(sample, GATK_target_coverage_flag)
    GATK_genome_coverage(sample, GATK_genome_coverage_flag)
    sys.exit(0)
