#!/usr/bin/env python

from omics_pipe.parameters.default_parameters import default_parameters
from omics_pipe.utils import *
p = Bunch(default_parameters)


def GATK_localRealignIndel_step1(sample, GATK_localRealignIndel_step1_flag):
    '''GATK preprocessing steps for whole exome sequencing.

    input:
        sorted.rg.md.bam
    output:
        indel_calls.interval_list
    citation:
        McKenna A, Hanna M, Banks E, Sivachenko A, Cibulskis K, Kernytsky A, Garimella K, Altshuler D, Gabriel S, Daly M, DePristo MA (2010). The Genome Analysis Toolkit: a MapReduce framework for analyzing next-generation DNA sequencing data. Genome Res. 20:1297-303.
    link:
        http://www.broadinstitute.org/gatk/
    parameters from parameters file:
        BWA_RESULTS:

        SAMPLE:

        TEMP_DIR:

        GATK_VERSION:

        GENOME:

        TARGET_FLANKS_FILE:

        BWA_INDEX:

        GATK_THREADS:

        DBSNP_REF:

        '''

    spawn_job(jobname = 'GATK_localRealignIndel_step1', SAMPLE = sample, LOG_PATH = p.LOG_PATH, RESULTS_EMAIL = p.RESULTS_EMAIL, SCHEDULER = p.SCHEDULER, walltime = "240:00:00", queue = p.QUEUE, nodes = 1, ppn = 2, memory = "10gb", script = "/GATK_realign_known_indels_step1_DRAW.sh", args_list = [p.BWA_RESULTS, sample, p.TEMP_DIR, p.GATK_VERSION, p.GENOME, p.TARGET_FLANKS_FILE, p.BWA_INDEX, p.GATK_THREADS, p.DBSNP])
    job_status(jobname = 'GATK_localRealignIndel_step1', resultspath = p.BWA_RESULTS, SAMPLE = sample,  outputfilename = sample + "/" + sample + ".indel_calls.interval_list", FLAG_PATH = p.FLAG_PATH)
    return


def GATK_localRealignIndel_step2(sample, GATK_localRealignIndel_step2_flag):
    '''GATK preprocessing steps for whole exome sequencing.

    input:
        sorted.rg.md.bam
    output:
        indel_realign.bam
    citation:
        McKenna A, Hanna M, Banks E, Sivachenko A, Cibulskis K, Kernytsky A, Garimella K, Altshuler D, Gabriel S, Daly M, DePristo MA (2010). The Genome Analysis Toolkit: a MapReduce framework for analyzing next-generation DNA sequencing data. Genome Res. 20:1297-303.
    link:
        http://www.broadinstitute.org/gatk/
    parameters from parameters file:
        BWA_RESULTS:

        SAMPLE:

        TEMP_DIR:

        GATK_VERSION:

        GENOME:

        TARGET_FLANKS_FILE:

        BWA_INDEX:

        GATK_THREADS

        DBSNP_REF_INDELS
        '''

    spawn_job(jobname = 'GATK_localRealignIndel_step2', SAMPLE = sample, LOG_PATH = p.LOG_PATH, RESULTS_EMAIL = p.RESULTS_EMAIL, SCHEDULER = p.SCHEDULER, walltime = "240:00:00", queue = p.QUEUE, nodes = 1, ppn = 4, memory = "10gb", script = "/GATK_realign_known_indels_step2_DRAW.sh", args_list = [p.BWA_RESULTS, sample, p.TEMP_DIR, p.GATK_VERSION, p.GENOME, p.TARGET_FLANKS_FILE, p.DBSNP_REF_INDELS])
    job_status(jobname = 'GATK_localRealignIndel_step2', resultspath = p.BWA_RESULTS, SAMPLE = sample,  outputfilename = sample + "/" + sample + ".indel_realign.bam", FLAG_PATH = p.FLAG_PATH)
    return

if __name__ == '__main__':
    GATK_localRealignIndel_step1(sample, GATK_localRealignIndel_step1_flag)
    GATK_localRealignIndel_step2(sample, GATK_localRealignIndel_step2_flag)
    sys.exit(0)
