#!/usr/bin/env python

from omics_pipe.parameters.default_parameters import default_parameters
from omics_pipe.utils import *
p = Bunch(default_parameters)


def GATK_recal_countCovariates(sample, GATK_recal_countCovariates_flag):
    '''GATK preprocessing steps for whole exome sequencing.

    input:
        indel_realign.bam
    output:
        recal_data.csv
    citation:
        McKenna A, Hanna M, Banks E, Sivachenko A, Cibulskis K, Kernytsky A, Garimella K, Altshuler D, Gabriel S, Daly M, DePristo MA (2010). The Genome Analysis Toolkit: a MapReduce framework for analyzing next-generation DNA sequencing data. Genome Res. 20:1297-303.
    link:
        http://www.broadinstitute.org/gatk/
    parameters from parameters file:
        BWA_RESULTS:

        TEMP_DIR:

        GATK_VERSION:

        GENOME:

        DBSNP:

        TARGET_FLANKS_FILE:

        '''

    spawn_job(jobname = 'GATK_recal_countCovariates', SAMPLE = sample, LOG_PATH = p.LOG_PATH, RESULTS_EMAIL = p.RESULTS_EMAIL, SCHEDULER = p.SCHEDULER, walltime = "240:00:00", queue = p.QUEUE, nodes = 1, ppn = 4, memory = "10gb", script = "/GATK_recal_countCovariates_DRAW.sh", args_list = [p.BWA_RESULTS, sample, p.TEMP_DIR, p.GATK_VERSION, p.GENOME, p.DBSNP, p.TARGET_FLANKS_FILE])
    job_status(jobname = 'GATK_recal_countCovariates', resultspath = p.BWA_RESULTS, SAMPLE = sample,  outputfilename = sample + "/" + "csv" + "/"+ sample +".recal_data.csv", FLAG_PATH = p.FLAG_PATH)
    return


def GATK_recal_tableRecalibration(sample, GATK_recal_tableRecalibration_flag):
    '''GATK preprocessing steps for whole exome sequencing.

    input:
        indel_realign.bam
    output:
        recal.FULL.bam
    citation:
        McKenna A, Hanna M, Banks E, Sivachenko A, Cibulskis K, Kernytsky A, Garimella K, Altshuler D, Gabriel S, Daly M, DePristo MA (2010). The Genome Analysis Toolkit: a MapReduce framework for analyzing next-generation DNA sequencing data. Genome Res. 20:1297-303.
    link:
        http://www.broadinstitute.org/gatk/
    parameters from parameters file:
        BWA_RESULTS:

        TEMP_DIR:

        GATK_VERSION:

        GENOME:

        DBSNP:

        TARGET_FLANKS_FILE:

        '''

    spawn_job(jobname = 'GATK_recal_tableRecalibration', SAMPLE = sample, LOG_PATH = p.LOG_PATH, RESULTS_EMAIL = p.RESULTS_EMAIL, SCHEDULER = p.SCHEDULER, walltime = "240:00:00", queue = p.QUEUE, nodes = 1, ppn = 4, memory = "10gb", script = "/GATK_recal_tableRecalibration_DRAW"  + ".sh", args_list = [p.BWA_RESULTS, sample, p.TEMP_DIR, p.GATK_VERSION, p.GENOME, p.DBSNP, p.TARGET_FLANKS_FILE])
    job_status(jobname = 'GATK_recal_tableRecalibration', resultspath = p.BWA_RESULTS, SAMPLE = sample,  outputfilename = sample + "/" + sample + "_recal.FULL.bam", FLAG_PATH = p.FLAG_PATH)
    return

if __name__ == '__main__':
    GATK_recal_countCovariates(sample, GATK_recal_countCovariates_flag)
    GATK_recal_tableRecalibration(sample, GATK_recal_tableRecalibration_flag)
    sys.exit(0)
