#!/usr/bin/env python

from omics_pipe.parameters.default_parameters import default_parameters
from omics_pipe.utils import *
p = Bunch(default_parameters)

def bwa_mem_draw(sample,bwa_mem_draw_flag):
    '''BWA aligner with BWA-MEM algorithm.

    input:
        .fastq
    output:
        .sam
    citation:
        Li H. and Durbin R. (2009) Fast and accurate short read alignment with Burrows-Wheeler transform. Bioinformatics, 25, 1754-1760. [PMID: 19451168]
    link:
        http://bio-bwa.sourceforge.net/bwa.shtml
    parameters from parameters file:
        BWA_RESULTS:

        TEMP_DIR:

        RG_STR:

        BWA_VERSION:

        GENOME:

        RAW_DATA_DIR:

        BWA_OPTIONS:

        COMPRESSION:
    '''
    spawn_job(jobname = 'bwa_mem_draw', SAMPLE = sample, LOG_PATH = p.LOG_PATH, RESULTS_EMAIL = p.RESULTS_EMAIL, SCHEDULER = p.SCHEDULER, walltime = "240:00:00", queue = p.QUEUE, nodes = 1, ppn = "30" , memory = "10240", script = "/bwa_drmaa_" + p.ENDS + "_DRAW.sh", args_list = [p.BWA_RESULTS, p.TEMP_DIR, p.RG_STR, p.BWA_VERSION, p.BWA_INDEX, sample, p.RAW_DATA_DIR, p.BWA_OPTIONS, p.COMPRESSION])
    job_status(jobname = 'bwa_mem_draw', resultspath = p.BWA_RESULTS, SAMPLE = sample, outputfilename = sample + "/" + sample + "_sorted.bam", FLAG_PATH = p.FLAG_PATH)
    return
