#!/usr/bin/env python

from omics_pipe.parameters.default_parameters import default_parameters
from omics_pipe.utils import *
p = Bunch(default_parameters)


def picard_meanQbycycle(sample, picard_meanQbycycle_flag):
    '''Picard tools meanQbycycle.

    input:
        recal.FULL.bam
    output:
        qualityByCycle_$2.pdf
    citation:
        http://picard.sourceforge.net/
    link:
        http://picard.sourceforge.net/
    parameters from parameters file:
        BWA_RESULTS:

        SAMPLE:

        TEMP_DIR:

        '''

    spawn_job(jobname = 'picard_meanQbycycle', SAMPLE = sample, LOG_PATH = p.LOG_PATH, RESULTS_EMAIL = p.RESULTS_EMAIL, SCHEDULER = p.SCHEDULER, walltime = "240:00:00", queue = p.QUEUE, nodes = 1, ppn = 2, memory = "8gb", script = "/picard_meanQbycycle_DRAW.sh", args_list = [p.BWA_RESULTS, sample, p.TEMP_DIR])
    job_status(jobname = 'picard_meanQbycycle', resultspath = p.BWA_RESULTS, SAMPLE = sample,  outputfilename = sample + "/" + "qualityByCycle_" + sample + ".pdf", FLAG_PATH = p.FLAG_PATH)
    return


def picard_meanQScDis(sample, picard_meanQScDis_flag):
    '''Picard tools meanQScDis.

    input:
        recal.FULL.bam
    output:
        quality_filter_score_$2.pdf
    citation:
        http://picard.sourceforge.net/
    link:
        http://picard.sourceforge.net/
    parameters from parameters file:
        BWA_RESULTS:

        SAMPLE:

        TEMP_DIR:

        '''

    spawn_job(jobname = 'picard_meanQScDis', SAMPLE = sample, LOG_PATH = p.LOG_PATH, RESULTS_EMAIL = p.RESULTS_EMAIL, SCHEDULER = p.SCHEDULER, walltime = "240:00:00", queue = p.QUEUE, nodes = 1, ppn = 2, memory = "8gb", script = "/picard_meanQScDis_DRAW.sh", args_list = [p.BWA_RESULTS, sample, p.TEMP_DIR])
    job_status(jobname = 'picard_meanQScDis', resultspath = p.BWA_RESULTS, SAMPLE = sample,  outputfilename = sample + "/" + "quality_filter_score_"+ sample + ".pdf", FLAG_PATH = p.FLAG_PATH)
    return


def picard_hsMetrics(sample, picard_hsMetrics_flag):
    '''Picard tools hsMetrics.

    input:
        recal.FULL.bam
    output:
        Gc_bias_$2.pdf
    citation:
        http://picard.sourceforge.net/
    link:
        http://picard.sourceforge.net/
    parameters from parameters file:
        BWA_RESULTS:

        SAMPLE:

        TEMP_DIR:

        GENOME:

        '''

    spawn_job(jobname = 'picard_hsMetrics', SAMPLE = sample, LOG_PATH = p.LOG_PATH, RESULTS_EMAIL = p.RESULTS_EMAIL, SCHEDULER = p.SCHEDULER, walltime = "240:00:00", queue = p.QUEUE, nodes = 1, ppn = 2, memory = "8gb", script = "/picard_hsMetrics_DRAW.sh", args_list = [p.BWA_RESULTS, sample, p.TEMP_DIR, p.GENOME])
    job_status(jobname = 'picard_hsMetrics', resultspath = p.BWA_RESULTS, SAMPLE = sample,  outputfilename = sample + "/" + "Gc_bias_"+ sample + ".pdf", FLAG_PATH = p.FLAG_PATH)
    return


def picard_collectInsertSizeMetrics(sample, picard_collectInsertSizeMetrics_flag):
    '''Picard tools collectInsertSizeMetrics.

    input:
        recal.FULL.bam
    output:
        hst_Insert_$2.pdf
    citation:
        http://picard.sourceforge.net/
    link:
        http://picard.sourceforge.net/
    parameters from parameters file:
        BWA_RESULTS:

        SAMPLE:

        TEMP_DIR:

        GENOME:

        '''

    spawn_job(jobname = 'picard_collectInsertSizeMetrics', SAMPLE = sample, LOG_PATH = p.LOG_PATH, RESULTS_EMAIL = p.RESULTS_EMAIL, SCHEDULER = p.SCHEDULER, walltime = "240:00:00", queue = p.QUEUE, nodes = 1, ppn = 2, memory = "8gb", script = "/picard_collectInsertSizeMetrics_DRAW.sh", args_list = [p.BWA_RESULTS, sample, p.TEMP_DIR])
    job_status(jobname = 'picard_collectInsertSizeMetrics', resultspath = p.BWA_RESULTS, SAMPLE = sample,  outputfilename = sample + "/" + "hst_Insert_"+ sample + ".pdf", FLAG_PATH = p.FLAG_PATH)
    return


if __name__ == '__main__':
    picard_meanQbycycle(sample, picard_meanQbycycle_flag)
    picard_meanQScDis(sample, picard_meanQScDis_flag)
    picard_hsMetrics(sample, picard_hsMetrics_flag)
    picard_collectInsertSizeMetrics(sample, picard_collectInsertSizeMetrics_flag)

    sys.exit(0)
