#!/usr/bin/env python

from omics_pipe.parameters.default_parameters import default_parameters
from omics_pipe.utils import *
p = Bunch(default_parameters)

def samtools(sample, samtools_flag):
    ''' SAM<->BAM conversion
    input:
        *.rg.bam
    output:
        _merged.bam
    citation:
        "samtools"
    link:
         http://htslib.org/
    parameters from parameters file:
        BWA_RESULTS:

        SAMPLE:

        TEMP_DIR:

    '''
    spawn_job(jobname = 'samtoolsMergebam', SAMPLE = sample, LOG_PATH = p.LOG_PATH, RESULTS_EMAIL = p.RESULTS_EMAIL, SCHEDULER = p.SCHEDULER, walltime = "240:00:00", queue = p.QUEUE, nodes = 1, ppn = 2, memory = "8gb", script = "samtools_mergebam_DRAW.sh", args_list = [p.BWA_RESULTS, sample, p.TEMP_DIR])
    job_status(jobname = 'samtoolsMergebam', resultspath = p.BWA_RESULTS, SAMPLE = sample, outputfilename = sample + "/" + sample + "_merged.bam", FLAG_PATH = p.FLAG_PATH)
    return

def samtools_doFlagStat(sample, samtools_doFlagStat_flag):
    '''
    input:
        _merged.bam
    output:
        .flagstat
    citation:
        "samtools"
    link:
         http://htslib.org/
    parameters from parameters file:
        BWA_RESULTS:

        SAMPLE:

        TEMP_DIR:

    '''
    spawn_job(jobname = 'samtoolsDoFlagStat', SAMPLE = sample, LOG_PATH = p.LOG_PATH, RESULTS_EMAIL = p.RESULTS_EMAIL, SCHEDULER = p.SCHEDULER, walltime = "240:00:00", queue = p.QUEUE, nodes = 1, ppn = 2, memory = "5gb", script = "/doFlagStat_DRAW.sh", args_list = [p.BWA_RESULTS, sample, p.TEMP_DIR])
    job_status(jobname = 'samtoolsDoFlagStat', resultspath = p.BWA_RESULTS, SAMPLE = sample, outputfilename = sample + "/stat/" + sample + ".flagstat", FLAG_PATH = p.FLAG_PATH)
    return

if __name__ == '__main__':
    samtools(sample, samtools_flag)
    samtools_doFlagStat(sample, samtools_doFlagStat_flag)
    sys.exit(0)
