#!/bin/bash
set -x

#Source modules for current shell
source /home/sgeadmin/.bash_profile


####INPUTS: $1: BWA_RESULTS $2 SAMPLE $3: TEMP_DIR $4 GATK_VERSION $5 GENOME  $6 TARGET_FLANKS_FILE  $7 BWA_INDEX  $8 GATK_THREADS  $9 DBSNP_REF_INDELS


# Check for intervals file
if [ ! -s "$1/$2/$2.indel_calls.interval_list" ];then
  echo "Error: Missing interval file: " $2.indel_calls.interval_list " from realignIndelS1"
  exit 100
fi


######################## GATK IndelRealigner ###################

java -Xmx5g -jar $GATK_HOME \
   -T IndelRealigner \
   -R $5 \
   -I $1/$2/$2_sorted.rg.md.bam  \
   -targetIntervals $1/$2/$2.indel_calls.interval_list \
   -o $1/$2/$2.indel_realign.bam \
   --bam_compression 7 \
   --maxReadsInMemory 200000 \
   -known $9

#force error when missing output
if [ ! -s "$1/$2/$2.indel_realign.bam" ]
then
 echo "Missing output BAM $2.indel_realign.bam"
 exit 100
fi

# Check BAM EOF
BAM_28=$(tail -c 28 $2.indel_realign.bam|xxd -p)
if [ "$MAGIC28" != "$BAM_28" ]
then
  echo "Error with BAM EOF" 1>&2
  exit 100
fi


exit 0
